@@ -30,11 +30,11 @@ def mkMain():
     fsm.If(valid).goto_next()
 
     # read rdata
-    ack, valid, last = myaxi.push_read_data(rdata, counter, cond=fsm)
+    ack, last = myaxi.push_read_data(rdata, counter, cond=fsm)
     fsm.If(ack)(
         rdata(rdata + 1)
     )
-    fsm.If(valid, last).goto_next()
+    fsm.If(last).goto_next()
 
     fsm.goto_init()
 
@@ -103,7 +103,7 @@ def mkTest():
                      params=m.connect_params(main),
                      ports=m.connect_ports(main))
 
-    simulation.setup_waveform(m, uut, m.get_vars())
+    # simulation.setup_waveform(m, uut, m.get_vars())
     simulation.setup_clock(m, clk, hperiod=5)
     init = simulation.setup_reset(m, rst, m.make_reset(), period=100)
 
