@@ -118,12 +118,6 @@ module test;
   );
 
 
-  initial begin
-    $dumpfile("uut.vcd");
-    $dumpvars(0, uut, CLK, RST, myaxi_awaddr, myaxi_awlen, myaxi_awsize, myaxi_awburst, myaxi_awlock, myaxi_awcache, myaxi_awprot, myaxi_awqos, myaxi_awuser, myaxi_awvalid, myaxi_awready, myaxi_wdata, myaxi_wstrb, myaxi_wlast, myaxi_wvalid, myaxi_wready, myaxi_bresp, myaxi_bvalid, myaxi_bready, myaxi_araddr, myaxi_arlen, myaxi_arsize, myaxi_arburst, myaxi_arlock, myaxi_arcache, myaxi_arprot, myaxi_arqos, myaxi_aruser, myaxi_arvalid, myaxi_arready, myaxi_rdata, myaxi_rresp, myaxi_rlast, myaxi_rvalid, myaxi_rready, waddr, _awlen, _tmp_0, _tmp_1, _tmp_2, _tmp_3);
-  end
-
-
   initial begin
     CLK = 0;
     forever begin
@@ -260,43 +254,41 @@ module main
   assign myaxi_arprot = 0;
   assign myaxi_arqos = 0;
   assign myaxi_aruser = 0;
-  reg [3-1:0] outstanding_wcount_0;
   assign myaxi_rready = 0;
   reg [32-1:0] fsm;
   localparam fsm_init = 0;
-  reg [9-1:0] counter_1;
+  reg [9-1:0] _tmp_0;
   reg _myaxi_cond_0_1;
-  reg last_2;
-  wire _dataflow_tmp_all_valid_3;
+  reg _tmp_1;
+  wire _dataflow_tmp_all_valid_2;
   wire [32-1:0] _dataflow_counter_odata_1;
   wire _dataflow_counter_ovalid_1;
   wire _dataflow_counter_oready_1;
-  assign _dataflow_counter_oready_1 = (counter_1 > 0) && (outstanding_wcount_0 < 6) && (myaxi_wready || !myaxi_wvalid) && _dataflow_tmp_all_valid_3;
+  assign _dataflow_counter_oready_1 = (_tmp_0 > 0) && (myaxi_wready || !myaxi_wvalid) && _dataflow_tmp_all_valid_2;
   wire [1-1:0] _dataflow_eq_odata_7;
   wire _dataflow_eq_ovalid_7;
   wire _dataflow_eq_oready_7;
-  assign _dataflow_eq_oready_7 = (counter_1 > 0) && (outstanding_wcount_0 < 6) && (myaxi_wready || !myaxi_wvalid) && _dataflow_tmp_all_valid_3;
-  assign _dataflow_tmp_all_valid_3 = _dataflow_counter_ovalid_1 && _dataflow_eq_ovalid_7;
+  assign _dataflow_eq_oready_7 = (_tmp_0 > 0) && (myaxi_wready || !myaxi_wvalid) && _dataflow_tmp_all_valid_2;
+  assign _dataflow_tmp_all_valid_2 = _dataflow_counter_ovalid_1 && _dataflow_eq_ovalid_7;
   reg _myaxi_cond_1_1;
   reg [32-1:0] sum;
   reg _seq_cond_0_1;
 
   always @(posedge CLK) begin
     if(RST) begin
-      outstanding_wcount_0 <= 0;
       myaxi_araddr <= 0;
       myaxi_arlen <= 0;
       myaxi_arvalid <= 0;
       myaxi_awaddr <= 0;
       myaxi_awlen <= 0;
       myaxi_awvalid <= 0;
-      counter_1 <= 0;
+      _tmp_0 <= 0;
       _myaxi_cond_0_1 <= 0;
       myaxi_wdata <= 0;
       myaxi_wvalid <= 0;
       myaxi_wlast <= 0;
       myaxi_wstrb <= 0;
-      last_2 <= 0;
+      _tmp_1 <= 0;
       _myaxi_cond_1_1 <= 0;
     end else begin
       if(_myaxi_cond_0_1) begin
@@ -305,46 +297,40 @@ module main
       if(_myaxi_cond_1_1) begin
         myaxi_wvalid <= 0;
         myaxi_wlast <= 0;
-        last_2 <= 0;
-      end 
-      if(myaxi_wlast && myaxi_wvalid && myaxi_wready && !(myaxi_bvalid && myaxi_bready) && (outstanding_wcount_0 < 7)) begin
-        outstanding_wcount_0 <= outstanding_wcount_0 + 1;
-      end 
-      if(!(myaxi_wlast && myaxi_wvalid && myaxi_wready) && (myaxi_bvalid && myaxi_bready) && (outstanding_wcount_0 > 0)) begin
-        outstanding_wcount_0 <= outstanding_wcount_0 - 1;
+        _tmp_1 <= 0;
       end 
       myaxi_araddr <= 0;
       myaxi_arlen <= 0;
       myaxi_arvalid <= 0;
-      if((fsm == 0) && ((myaxi_awready || !myaxi_awvalid) && (counter_1 == 0))) begin
+      if((fsm == 0) && ((myaxi_awready || !myaxi_awvalid) && (_tmp_0 == 0))) begin
         myaxi_awaddr <= 1024;
         myaxi_awlen <= 63;
         myaxi_awvalid <= 1;
-        counter_1 <= 64;
+        _tmp_0 <= 64;
       end 
-      if((fsm == 0) && ((myaxi_awready || !myaxi_awvalid) && (counter_1 == 0)) && 0) begin
+      if((fsm == 0) && ((myaxi_awready || !myaxi_awvalid) && (_tmp_0 == 0)) && 0) begin
         myaxi_awvalid <= 0;
       end 
       _myaxi_cond_0_1 <= 1;
       if(myaxi_awvalid && !myaxi_awready) begin
         myaxi_awvalid <= myaxi_awvalid;
       end 
-      if(_dataflow_eq_odata_7 && (_dataflow_counter_ovalid_1 && ((counter_1 > 0) && (outstanding_wcount_0 < 6) && (myaxi_wready || !myaxi_wvalid) && _dataflow_tmp_all_valid_3)) && ((counter_1 > 0) && (outstanding_wcount_0 < 6) && (myaxi_wready || !myaxi_wvalid) && (counter_1 > 0))) begin
+      if(_dataflow_eq_odata_7 && (_dataflow_counter_ovalid_1 && ((_tmp_0 > 0) && (myaxi_wready || !myaxi_wvalid) && _dataflow_tmp_all_valid_2)) && ((_tmp_0 > 0) && (myaxi_wready || !myaxi_wvalid) && (_tmp_0 > 0))) begin
         myaxi_wdata <= _dataflow_counter_odata_1;
         myaxi_wvalid <= 1;
         myaxi_wlast <= 0;
         myaxi_wstrb <= { 4{ 1'd1 } };
-        counter_1 <= counter_1 - 1;
+        _tmp_0 <= _tmp_0 - 1;
       end 
-      if(_dataflow_eq_odata_7 && (_dataflow_counter_ovalid_1 && ((counter_1 > 0) && (outstanding_wcount_0 < 6) && (myaxi_wready || !myaxi_wvalid) && _dataflow_tmp_all_valid_3)) && ((counter_1 > 0) && (outstanding_wcount_0 < 6) && (myaxi_wready || !myaxi_wvalid) && (counter_1 > 0)) && (counter_1 == 1)) begin
+      if(_dataflow_eq_odata_7 && (_dataflow_counter_ovalid_1 && ((_tmp_0 > 0) && (myaxi_wready || !myaxi_wvalid) && _dataflow_tmp_all_valid_2)) && ((_tmp_0 > 0) && (myaxi_wready || !myaxi_wvalid) && (_tmp_0 > 0)) && (_tmp_0 == 1)) begin
         myaxi_wlast <= 1;
-        last_2 <= 1;
+        _tmp_1 <= 1;
       end 
       _myaxi_cond_1_1 <= 1;
       if(myaxi_wvalid && !myaxi_wready) begin
         myaxi_wvalid <= myaxi_wvalid;
         myaxi_wlast <= myaxi_wlast;
-        last_2 <= last_2;
+        _tmp_1 <= _tmp_1;
       end 
     end
   end
@@ -442,7 +428,7 @@ module main
           end 
         end
         fsm_1: begin
-          if(last_2 && myaxi_wvalid && myaxi_wready) begin
+          if(_tmp_1 && myaxi_wvalid && myaxi_wready) begin
             fsm <= fsm_2;
           end 
         end
